function [u,v,time] = Wave1D(u,v,FinalTime,f,g,Periodic)

% function [u,v,time] = Wave1D(u,v,FinalTime,f,g,Periodic)
% Purpose  : Integrate 1D Wave equations until FinalTime starting with
%            initial conditions u and v
%
% By Allan P. Engsig-Karup.

Globals1D;
time = 0;

% Runge-Kutta residual storage  
resu = zeros(Np,K); resv = zeros(Np,K);

% compute time step size
xmin = min(abs(x(1,:)-x(2,:)));
CFL=0.25; dt = CFL*xmin; dt = .5*dt;
Nsteps = ceil(FinalTime/dt); dt = FinalTime/Nsteps; 

% outer time step loop 
for tstep=1:Nsteps
    for INTRK = 1:5
        timelocal = time + rk4c(INTRK)*dt;
        if Periodic
%             [rhsu,rhsv] = WaveRHS1DCentralPeriodic(u,v,timelocal);
            [rhsu,rhsv] = WaveRHS1DUpwindPeriodic(u,v,timelocal);
        else
            [rhsu,rhsv] = WaveRHS1DUpwindFinite(u,v,timelocal,f,g);
        end
        resu = rk4a(INTRK)*resu + dt*rhsu;
        resv = rk4a(INTRK)*resv + dt*rhsv;
        u = u+rk4b(INTRK)*resu;
        v = v+rk4b(INTRK)*resv;
    end
    
    if max(u(:))>10
        disp('blowup...');
        wer % forced break
    end

    % Increment time
    time = time+dt;
%     if mod(tstep,20)==0
%         plot(x,f(x+time)+g(x-time),'k-',x,u,'rx');
%         axis([min(x(:)) max(x(:)) -1.25 1.25])
%         xlabel('x'), ylabel('u,v'), drawnow
%     end
end
return
