close all, clear all, clc
% Driver script for solving the 1D wave equations
% on either a finite or periodic domain
%
% By Allan P. Engsig-Karup.
Globals1D;

% Order of polymomials used for approximation 
N = 6;
K = 4;
FinalTime = 100;
Periodic = 1; % 0 = no, 1 = yes

% Generate simple mesh
[Nv, VX, K, EToV] = MeshGen1D(0.0,2*pi,K);

% Initialize solver and construct grid and metric
StartUp1D;

if Periodic
    vmapP(1)   = vmapM(end);  vmapP(end) = vmapM(1);
end

% Define initial wave functions
f = @(s) sin(s)*0;   % wave form propagating to the left
g = @(s) sin(s); % wave form propagating to the right

% Set initial conditions
u =  f(x) + g(x); % intial disturbance
v = -f(x) + g(x); % 

% Solve Problem
[u,v,time] = Wave1D(u,v,FinalTime,f,g,Periodic);

% Plot exact u and computed u
plot(x,f(x+time)+g(x-time),'k-',x,u,'rx');
axis([min(x(:)) max(x(:)) -1.25 1.25])
xlabel('x'), ylabel('u,v'), drawnow
