function [rhsu,rhsv] = WaveRHS1D(u,v,time,Periodic)

% function [rhsu,rhsv] = WaveRHS1D(u,v,time, Periodic)
% Purpose  : Evaluate RHS flux in 1D wave equations

Globals1D;

switch 1
    case 0 % central fluxes, periodic domain
        % form flux differences at faces
        df    = zeros(Nfp*Nfaces,K);
        df(:) = 0.5*nx(:).*(u(vmapM)-u(vmapP));

        dg    = zeros(Nfp*Nfaces,K);
        dg(:) = 0.5*nx(:).*(v(vmapM)-v(vmapP));

        % compute right hand sides of the semi-discrete PDE
        rhsu = -a*rx.*(Dr*v) + LIFT*(Fscale.*(dg));
        rhsv = -a*rx.*(Dr*u) + LIFT*(Fscale.*(df));

    case 1 % upwind fluxes, periodic domain
        % jumps in u and v
        du = u(vmapM)-u(vmapP);
        dv = v(vmapM)-v(vmapP);

        % form flux differences at faces
        df    = zeros(Nfp*Nfaces,K);
        df(:) = 0.5*a*nx(:).*dv-0.5*a*du;

        dg    = zeros(Nfp*Nfaces,K);
        dg(:) = 0.5*a*nx(:).*du-0.5*a*dv;

        % compute right hand sides of the semi-discrete PDE
        rhsu = -a*rx.*(Dr*v) + LIFT*(Fscale.*(df));
        rhsv = -a*rx.*(Dr*u) + LIFT*(Fscale.*(dg));        
        
    case 2 % upwind fluxed, finite domain
        % form flux differences at faces
        df    = zeros(Nfp*Nfaces,K);
%         vstar = 
        df(:) = v(vmapM)-vstar;

        dg    = zeros(Nfp*Nfaces,K);
        dg(:) = 0.5*nx(:).*(v(vmapM)-v(vmapP));

        % compute right hand sides of the semi-discrete PDE
        rhsu = -a*rx.*(Dr*v) + LIFT*(Fscale.*(dg));
        rhsv = -a*rx.*(Dr*u) + LIFT*(Fscale.*(df));
end
return
        

switch 0
    case 0 % central fluxes

        % form flux differences at faces
        df    = zeros(Nfp*Nfaces,K);
        df(:) = 0.5*nx(:).*(u(vmapM)-u(vmapP));

        dg    = zeros(Nfp*Nfaces,K);
        dg(:) = 0.5*nx(:).*(v(vmapM)-v(vmapP));

%         % impose boundary conditions
%         f = @(s) sin(s)*0; % wave form propagating to the left
%         g = @(s) sin(s); % wave form propagating to the right
% 
%         uleft  = f(0+time) + g(0-time);                 % x = 0
%         uright = f(max(x(:))+time) + g(max(x(:))-time); % x = L
%         uM = u(vmapM);
% 
%         vleft  = -f(0+time) + g(0-time);                % x = 0
%         vright = -f(max(x(:))+time) + g(max(x(:))-time);% x = L
%         vM = v(vmapM);
%         
%         % Dirichlet conditions
%         df(mapI) = 0.5*a*(uM(mapI)-uleft);
%         df(mapO) = 0.5*a*(uM(mapO)-uright);        
%         
%         % Neumann conditions
%         dg(mapI) = 0.5*a*(vM(mapI)-vleft);
%         dg(mapO) = 0.5*a*(vM(mapO)-vright);        
        
        % compute right hand sides of the semi-discrete PDE
        rhsu = -a*rx.*(Dr*v) + LIFT*(Fscale.*(dg));
        rhsv = -a*rx.*(Dr*u) + LIFT*(Fscale.*(df));
        
    case 1 % standard form

        % form flux differences at faces
        df    = zeros(Nfp*Nfaces,K);
        df(:) = 0.5*a*(u(vmapM)-u(vmapP)).*(nx(:)-(1-alpha));
        dg    = zeros(Nfp*Nfaces,K);
        dg(:) = 0.5*a*(v(vmapM)-v(vmapP)).*(nx(:)-(1-alpha));

        % impose boundary condition at x=0
        % uin      = -sin(a*time);
        % df(mapI) = 0.5*a*(u(vmapI)-uin).*(nx(mapI)-(1-alpha));
        % df(mapO) = 0;

        % compute right hand sides of the semi-discrete PDE
        rhsu = -a*rx.*(Dr*v) + LIFT*(Fscale.*(dg));
        rhsv =  a*rx.*(Dr*u) - LIFT*(Fscale.*(df));
        
    case 2 % upwind using jacobian matrix from quasi-linear system
        % solving the Riemann problem by upwinding on the characteristics
        A = [0 a; a 0];
        [R,D] = eig(A); % A=R*D*R';
        
        PL = diag(diag(D)<0); % select left moving waves
        PR = diag(diag(D)>0); % select right moving waves
        
        qM = [u(vmapM) v(vmapM)]; % interior
        qP = [u(vmapP) v(vmapP)]; % exterior
        nxx = [nx(:) nx(:)];
        
        % select qM when nx=1 and qP when nx=-1 at interface (upwinding rightmoving waves)
        % select qP when nx=1 and qM when nx=-1 at interface (upwinding leftmoving waves)
        fstar  = (R*PR*D*R')*(0.5*(nxx'+1).*qM'+0.5*(1-nxx').*qP') + ...
                 (R*PL*D*R')*(0.5*(nxx'+1).*qP'+0.5*(1-nxx').*qM');
        fstar = fstar';
        fluxdiff = (A*qM')' - fstar; % df = f^- - f^*
        
        df    = zeros(Nfp*Nfaces,K);
        dg    = zeros(Nfp*Nfaces,K);

        df(:) = fluxdiff(:,1);
        dg(:) = fluxdiff(:,2);
%         df(:) = v(vmapM) - fstar(:,1);
%         dg(:) = u(vmapM) - fstar(:,2);
        
        % compute right hand sides of the semi-discrete PDE
        rhsu = -a*rx.*(Dr*v) + LIFT*(Fscale.*(nx.*df));
        rhsv = -a*rx.*(Dr*u) + LIFT*(Fscale.*(nx.*dg));
        
end
return

