function [rhsu,rhsv] = WaveRHS1DUpwindFinite(u,v,time,f,g)
% function [rhsu] = WaveRHS1DUpwindFinite(u,v,time)
% Purpose  : Evaluate RHS flux in 1D wave equation system
%            by upwinding using Lax-Friedrichs-type flux
%
% By Allan P. Engsig-Karup.
Globals1D;

% jumps in u and v
du = u(vmapM)-u(vmapP); dv = v(vmapM)-v(vmapP);

% form flux differences at faces
df    = zeros(Nfp*Nfaces,K);
df(:) = 0.5*nx(:).*dv-0.5*du;

dg    = zeros(Nfp*Nfaces,K);
dg(:) = 0.5*nx(:).*du-0.5*dv;

% Impose left outer boundary
x0 = min(x(:));
uM = u(vmapI); vM = v(vmapI);
uP =  f(x0+time) + g(x0-time);
vP = -f(x0+time) + g(x0-time);
us = 0.5*( uP + vP - vM + uM );
vs = 0.5*( uP + vP + vM - uM );
df(mapI) = 0.5*nx(mapI)*(vM-vs)-0.5*(uM-us);
dg(mapI) = 0.5*nx(mapI)*(uM-us)-0.5*(vM-vs);

% Impose right outer boundary
x0 = max(x(:));
uM = u(vmapO); vM = v(vmapO); 
uP =  f(x0+time) + g(x0-time);
vP = -f(x0+time) + g(x0-time);
us = 0.5*( uM + vM - vP + uP );
vs = 0.5*( vP - uP + uM + vM );
df(mapO) = 0.5*nx(mapO)*(vM-vs)-0.5*(uM-us);
dg(mapO) = 0.5*nx(mapO)*(uM-us)-0.5*(vM-vs);

% compute right hand sides of the semi-discrete PDE
rhsu = -rx.*(Dr*v) + LIFT*(Fscale.*(df));
rhsv = -rx.*(Dr*u) + LIFT*(Fscale.*(dg));        
