function [rhsu,rhsv] = WaveRHS1DUpwindPeriodic(u,v,time)

% function [rhsu,rhsv] = WaveRHS1DUpwindPeriodic(u,v,time)
% Purpose  : Evaluate RHS flux in 1D wave equation system
%            upwinding using Lax-Friedrichs-type flux
%
% By Allan P. Engsig-Karup.

Globals1D;

% jumps in u and v
du = u(vmapM)-u(vmapP);
dv = v(vmapM)-v(vmapP);

% form flux differences at faces
df    = zeros(Nfp*Nfaces,K);
df(:) = 0.5*nx(:).*dv-0.5*du;

dg    = zeros(Nfp*Nfaces,K);
dg(:) = 0.5*nx(:).*du-0.5*dv;

% compute right hand sides of the semi-discrete PDE
rhsu = -rx.*(Dr*v) + LIFT*(Fscale.*(df));
rhsv = -rx.*(Dr*u) + LIFT*(Fscale.*(dg));        
